pragma solidity ^0.4.24;

import "./Token.sol";

contract ICO is Owned {

    address icoOnwer;
    Token public token;
    uint public rate;
    uint256 public tokensSold ;
    uint256 private _openingTime;
    uint256 private _closingTime;

    constructor (address _tokenAddress, uint256 openingTime, uint256 closingTime) public {
        token = Token(_tokenAddress);
        icoOnwer = token.owner();
        require(closingTime > openingTime);

        _openingTime = openingTime;
        _closingTime = closingTime;
    
    }
    
    function transferOwnership(address _newOwner) public onlyOwner {
        owner = _newOwner;
    }
     

    function buyToken() public payable {
        if(isOpen()){
            rate = 10000;
            require((msg.value * rate) <= token.balanceOf(address(this)));
            token.transfer(msg.sender, (msg.value * rate));
            tokensSold += (msg.value * rate);

        }
        else{
            revert();
        }
    }

    function tokenWithdraw() public onlyOwner {
        token.transfer(owner, token.balanceOf(address(this)));
    }

    function getBalance() public view returns (uint) {
        return token.balanceOf(msg.sender);
    }

    function getICOBalance() public view returns (uint) {
        return token.balanceOf(address(this));
    }

    function _getTokenAmount(uint256 _weiAmount) internal view returns (uint256) {
        uint256 etherAmount = _weiAmount / 1000000000000000000;
        return etherAmount*rate;
    }

    //timed ICO
    function openingTime() public view returns (uint256) {
        return _openingTime;
    }
    /**
  * @return the crowdsale closing time.
  */
    function closingTime() public view returns (uint256) {
        return _closingTime;
    }

 


    /**
     * @return true if the crowdsale is open, false otherwise.
     */
    function isOpen() public view returns (bool) {
        // solhint-disable-next-line not-rely-on-time
        return block.timestamp >= _openingTime && block.timestamp <= _closingTime;
    }

    /**
     * @dev Checks whether the period in which the crowdsale is open has already elapsed.
     * @return Whether crowdsale period has elapsed
     */
    function hasClosed() public view returns (bool) {
        // solhint-disable-next-line not-rely-on-time
        return block.timestamp > _closingTime;
    }

   

    function _forwardFunds() public onlyOwner {
        owner.transfer(address(this).balance);
    }

}

